import Image from 'next/image'

import { Container } from '@/components/Container'
import backgroundImage from '@/images/background-faqs.jpg'

const faqs = [
  [
    {
      question: 'Wie installiere ich die Software?',
      answer:
        'NaviLearn ist ein Saas-Produkt, das keine Installation erfordert. Sie können sofort in Ihrem Browser loslegen.',
    },
    {
      question: 'Wie füge ich neue Mitarbeiter hinzu?',
      answer:
        'Sie können neue Mitarbeiter über die Schaltfläche in der Teamübersicht hinzufügen.',
    },
    {
      question: 'Kann ich die Software auf mehreren Geräten verwenden?',
      answer:
        'Ja, Sie können NaviLearn auf beliebig vielen Geräten innerhalb eines Benutzerkontos verwenden.',
    },
  ],
]

export function Faqs() {
  return (
    <section
      id="faq"
      aria-labelledby="faq-title"
      className="relative overflow-hidden bg-slate-50 py-20 sm:py-32"
    >
      <Image
        className="absolute left-1/2 top-0 max-w-none -translate-y-1/4 translate-x-[-30%]"
        src={backgroundImage}
        alt=""
        width={1558}
        height={946}
        unoptimized
      />
      <Container className="relative">
        <div className="mx-auto max-w-2xl lg:mx-0">
          <h2
            id="faq-title"
            className="font-display text-3xl tracking-tight text-slate-900 sm:text-4xl"
          >
            Häufig gestellte Fragen
          </h2>
          <p className="mt-4 text-lg tracking-tight text-slate-700">
            Falls Sie hier keine Antwort auf Ihre Frage finden, zögern Sie
            nicht, uns eine E-Mail zu schreiben.
          </p>
        </div>
        <ul
          role="list"
          className="mx-auto mt-16 grid max-w-2xl grid-cols-1 gap-8 lg:max-w-none lg:grid-cols-1"
        >
          {faqs.map((column, columnIndex) => (
            <li key={columnIndex}>
              <ul role="list" className="flex flex-col gap-y-8">
                {column.map((faq, faqIndex) => (
                  <li key={faqIndex}>
                    <h3 className="font-display text-lg leading-7 text-slate-900">
                      {faq.question}
                    </h3>
                    <p className="mt-4 text-sm text-slate-700">{faq.answer}</p>
                  </li>
                ))}
              </ul>
            </li>
          ))}
        </ul>
      </Container>
    </section>
  )
}
